@@ -1,5 +1,5 @@
 from django.forms.widgets import MediaDefiningClass
-from django.template.base import Context
+from django.template import Context
 
 
 class Component(metaclass=MediaDefiningClass):
@@ -8,9 +8,6 @@ class Component(metaclass=MediaDefiningClass):
     def context(self, *args, **kwargs):
         return kwargs
 
-    def render(self, child_nodes, context: Context, component_context: dict) -> str:
-        for key, value in component_context.items():
-            context[key] = value
-        context["children"] = child_nodes.render(context)
+    def render(self, context: Context) -> str:
         template = context.template.engine.get_template(self.template)
         return template.render(context)
