@@ -3,9 +3,9 @@ from inspect import getfullargspec, unwrap
 from django import VERSION as DJ_VERSION
 from django import template
 from django.template.library import parse_bits
-from django.template.base import Context, NodeList
+from django.template import Context, NodeList
 
-from .arg_tag import ArgNode, ArgAlreadyDefinedException
+from .arg_tag import ArgNode, push_argtag_in_context, argtag_kwargs_from_context
 from .component import Component
 from .media import add_media
 
@@ -13,7 +13,7 @@ import typing as t
 
 
 def make_component_tag(
-    component_cls: t.Type[Component], self_closed: bool
+    component_cls: t.Type[Component], is_self_closed: bool
 ) -> t.Callable:
     component = component_cls()
     [_, *params], varargs, varkw, defaults, kwonly, kwonly_defaults, _ = getfullargspec(
@@ -40,11 +40,11 @@ def make_component_tag(
             args, kwargs = parse_bits(
                 parser, bits, params, varargs, varkw, defaults, False, component_name,
             )
-        if self_closed is False:
+        if is_self_closed:
+            nodelist = NodeList()
+        else:
             nodelist = parser.parse((f"/{component_name}",))
             parser.delete_first_token()
-        else:
-            nodelist = NodeList()
 
         return ComponentNode(component, nodelist, args, kwargs)
 
@@ -67,13 +67,20 @@ class ComponentNode(template.Node):
     def render(self, context: Context) -> str:
         self.register_media(context)
         args, kwargs = self.get_resolved_arguments(context)
-        child_nodes, args_tags = self.get_child_nodes_and_args_tags(context, kwargs)
-        kwargs.update(args_tags)
         with context.push():
+            context["children"], argtag_kwargs = self.render_between_tags(context)
+            kwargs.update(argtag_kwargs)
             component_context = self.component.context(*args, **kwargs)
-            rendered = self.component.render(child_nodes, context, component_context)
+            with context.update(component_context):
+                rendered = self.component.render(context)
         return rendered
 
+    def render_between_tags(self, context):
+        push_argtag_in_context(context)
+        children = self.nodelist.render(context)
+        argtag_kwargs = argtag_kwargs_from_context(context)
+        return children, argtag_kwargs
+
     def register_media(self, context):
         add_media(context, self.component.media)
 
@@ -81,25 +88,3 @@ class ComponentNode(template.Node):
         resolved_args = [var.resolve(context) for var in self.args]
         resolved_kwargs = {k: v.resolve(context) for k, v in self.kwargs.items()}
         return resolved_args, resolved_kwargs
-
-    def get_child_nodes_and_args_tags(self, context, kwargs):
-        child_nodes = NodeList()
-        args_tags = {}
-        for node in self.nodelist:
-            if isinstance(node, ArgNode):
-                arg_tag_name = node.name
-                if arg_tag_name in kwargs:
-                    raise ArgAlreadyDefinedException(
-                        f"An argument named {arg_tag_name} is already defined for {self.component.__class__.__name__}"
-                    )
-
-                arg_rendered = node.render_arg_tag(context)
-                if arg_tag_name in args_tags.keys():
-                    if not isinstance(args_tags[arg_tag_name], list):
-                        args_tags[arg_tag_name] = [args_tags[arg_tag_name]]
-                    args_tags[arg_tag_name].append(arg_rendered)
-                else:
-                    args_tags[arg_tag_name] = arg_rendered
-            else:
-                child_nodes.append(node)
-        return child_nodes, args_tags
