@@ -12,8 +12,10 @@ class Library(template.Library):
     def component(self, comp=None, name=None):
         def dec(comp: t.Type[Component]):
             component_name = name or comp.__name__
-            self.tag(component_name, make_component_tag(comp, self_closed=False))
-            self.tag(component_name + "/", make_component_tag(comp, self_closed=True))
+            self.tag(component_name, make_component_tag(comp, is_self_closed=False))
+            self.tag(
+                component_name + "/", make_component_tag(comp, is_self_closed=True)
+            )
             return comp
 
         if comp is None:
