@@ -1,11 +1,11 @@
 from django import template
 from django.forms.widgets import Media
-from django.template.base import Context
+from django.template import Context
 from django.utils.safestring import mark_safe
 
 from secrets import token_hex
 
-CONTEXT_KEY = "__django_component"
+MEDIA_CONTEXT_KEY = "__django_component__media"
 
 
 def media_tag(media_type):  # type: Literal["css", "js"] -> Callable
@@ -16,15 +16,15 @@ def media_tag(media_type):  # type: Literal["css", "js"] -> Callable
     return media
 
 
-def ensure_context_media(root_context: dict):
-    if not CONTEXT_KEY in root_context:
-        root_context[CONTEXT_KEY] = {"media": Media()}
+def ensure_media_context(root_context: dict):
+    if not MEDIA_CONTEXT_KEY in root_context:
+        root_context[MEDIA_CONTEXT_KEY] = Media()
 
 
 def add_media(context: Context, media):
     root_context = context.dicts[0]
-    ensure_context_media(root_context)
-    root_context[CONTEXT_KEY]["media"] += media
+    ensure_media_context(root_context)
+    root_context[MEDIA_CONTEXT_KEY] += media
 
 
 class MediaNode(template.Node):
@@ -38,8 +38,8 @@ class MediaNode(template.Node):
 
     def render_media(self, context):
         tags = []
-        if CONTEXT_KEY in context:
-            media = context[CONTEXT_KEY]["media"]
+        if MEDIA_CONTEXT_KEY in context:
+            media = context[MEDIA_CONTEXT_KEY]
             if self.media_type == "css":
                 tags = media.render_css()
             elif self.media_type == "js":
